@@ -17,9 +17,9 @@
 from minio import Minio
 
 client = Minio(
-    "play.min.io",
+    endpoint="play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
 
-client.delete_bucket_replication("my-bucket")
+client.delete_bucket_replication(bucket_name="my-bucket")
