@@ -17,9 +17,11 @@
 from minio import Minio
 
 client = Minio(
-    "play.min.io",
+    endpoint="play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
 
-config = client.get_object_retention("my-bucket", "my-object")
+config = client.get_object_retention(
+    bucket_name="my-bucket", object_name="my-object",
+)
