@@ -18,11 +18,11 @@ from minio import Minio
 from minio.sseconfig import Rule, SSEConfig
 
 client = Minio(
-    "play.min.io",
+    endpoint="play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
 
 client.set_bucket_encryption(
-    "my-bucket", SSEConfig(Rule.new_sse_s3_rule()),
+    bucket_name="my-bucket", config=SSEConfig(Rule.new_sse_s3_rule()),
 )
