@@ -18,7 +18,7 @@ from minio import Minio
 from minio.commonconfig import Tags
 
 client = Minio(
-    "play.min.io",
+    endpoint="play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
@@ -26,4 +26,4 @@ client = Minio(
 tags = Tags.new_bucket_tags()
 tags["Project"] = "Project One"
 tags["User"] = "jsmith"
-client.set_bucket_tags("my-bucket", tags)
+client.set_bucket_tags(bucket_name="my-bucket", tags=tags)
