@@ -21,10 +21,14 @@ from minio.commonconfig import GOVERNANCE
 from minio.retention import Retention
 
 client = Minio(
-    "play.min.io",
+    endpoint="play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
 
 config = Retention(GOVERNANCE, datetime.utcnow() + timedelta(days=10))
-client.set_object_retention("my-bucket", "my-object", config)
+client.set_object_retention(
+    bucket_name="my-bucket",
+    object_name="my-object",
+    config=config,
+)
